import { n as e } from "./rolldown-runtime-CJfroGDQ.js";
//#region __vite-optional-peer-dep:kerberos:proxy-agent-negotiate
var t;
//#endregion
e((() => {
	throw t = {}, Error("Could not resolve \"kerberos\" imported by \"proxy-agent-negotiate\". Is it installed?");
}))();
export { t as default };

//# sourceMappingURL=__vite-optional-peer-dep_kerberos_proxy-agent-negotiate-B5nVn_MB.js.map